ardt.datasets.dreamer.DreamerTrial
==================================

.. currentmodule:: ardt.datasets.dreamer

.. autoclass:: DreamerTrial

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DreamerTrial.__init__
      ~DreamerTrial.get_signal_metadata
      ~DreamerTrial.load_ground_truth
      ~DreamerTrial.load_preprocessed_signal_data
      ~DreamerTrial.load_raw_signal_data
      ~DreamerTrial.load_signal_data
      ~DreamerTrial.quadrant_to_arousal
      ~DreamerTrial.quadrant_to_valence
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DreamerTrial.dataset
      ~DreamerTrial.expected_response
      ~DreamerTrial.media_id
      ~DreamerTrial.media_name
      ~DreamerTrial.native_media_id
      ~DreamerTrial.native_participant_id
      ~DreamerTrial.participant_id
      ~DreamerTrial.participant_response
      ~DreamerTrial.signal_data_files
      ~DreamerTrial.signal_preprocessors
      ~DreamerTrial.signal_types
   
   